# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class DeleteEventRulesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DeleteEventRules','cms')
		self.set_method('POST')

	def get_RuleNamess(self):
		return self.get_query_params().get('RuleNames')

	def set_RuleNamess(self, RuleNamess):
		for depth1 in range(len(RuleNamess)):
			if RuleNamess[depth1] is not None:
				self.add_query_param('RuleNames.' + str(depth1 + 1) , RuleNamess[depth1])